Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2026)

Unified Diff: ash/common/accelerators/accelerator_controller.h

Issue 2586333003: Make mash register initial batch of accelerators in single shot. (Closed)
Patch Set: Fix comments. Move inline function to .h Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/accelerators/accelerator_controller.h
diff --git a/ash/common/accelerators/accelerator_controller.h b/ash/common/accelerators/accelerator_controller.h
index 38b9007edbebd90702c6fd39435788865b64e1ff..fc3263db4c5bcdcfbf3413509eb59dcf57bf5239 100644
--- a/ash/common/accelerators/accelerator_controller.h
+++ b/ash/common/accelerators/accelerator_controller.h
@@ -10,6 +10,7 @@
#include <map>
#include <memory>
#include <set>
+#include <vector>
#include "ash/ash_export.h"
#include "ash/common/accelerators/accelerator_table.h"
@@ -60,10 +61,10 @@ class ASH_EXPORT AcceleratorController
RESTRICTION_PREVENT_PROCESSING_AND_PROPAGATION
};
- // Registers a global keyboard accelerator for the specified target. If
- // multiple targets are registered for an accelerator, a target registered
- // later has higher priority.
- void Register(const ui::Accelerator& accelerator,
+ // Registers global keyboard accelerators for the specified target. If
+ // multiple targets are registered for any given accelerator, a target
+ // registered later has higher priority.
+ void Register(const std::vector<ui::Accelerator>& accelerators,
ui::AcceleratorTarget* target);
// Unregisters the specified keyboard accelerator for the specified target.
« no previous file with comments | « ash/accelerators/accelerator_controller_unittest.cc ('k') | ash/common/accelerators/accelerator_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698